Module content_stream

Module content_stream 

Content stream operator tokenization (Stage 1).

Tokenizes content stream bytes into a sequence of PDF operators. This module understands the PostScript-like operand stack + operator keyword pattern but not the semantics of operators.

rpdfium-parser:   &[u8] → Vec<Operator>          (tokenization — syntactic)
rpdfium-page:     Vec<Operator> → DisplayTree     (interpretation — semantic)

Enums

Operand
A content stream operand value.
Operator
A parsed content stream operator with its operands.
TextArrayElement
An element in a TJ (show text array) operator.

Functions

tokenize_content_stream
Tokenize a content stream into a sequence of operators.