pub struct PageOffsetHintTable {
pub min_objects: u32,
pub first_page_offset: u64,
pub min_page_length: u32,
pub bits_objects_delta: u8,
pub bits_length_delta: u8,
pub entries: Vec<PageHintEntry>,
}Expand description
The page offset hint table (PDF spec Annex F.3).
Fields
min_objects: u32Minimum number of objects in a page.
first_page_offset: u64Location of first page’s object (offset from start of file).
min_page_length: u32Minimum page length in bytes.
bits_objects_delta: u8Number of bits needed to represent difference from min objects.
bits_length_delta: u8Number of bits needed to represent difference from min length.
entries: Vec<PageHintEntry>Per-page entries.