Module linearized_header

Module linearized_header 

Linearization detection.

A linearized PDF has its first indirect object contain a /Linearized key in its dictionary. This module detects this marker and extracts the linearization parameters.

Structs

LinearizedInfo
Information extracted from a linearization dictionary.

Functions

detect_linearized
Detect whether a PDF is linearized by checking the first indirect object.