pub enum StreamData {
Raw {
offset: u64,
length: u64,
},
Decoded {
data: Vec<u8>,
},
}Expand description
Represents the raw (undecoded) data of a PDF stream.
Stream data is not read or decoded at parse time. Only the byte range within the source data is recorded for later on-demand decoding.
Variants
Raw
Undecoded: byte range within source data.
Decoded
Already decoded/generated data (used by editing operations).