pub fn get_object_from_stream(
contents: &ObjectStreamContents,
index: u32,
) -> Option<&Object>Expand description
Get a specific object from a parsed object stream by its index.
pub fn get_object_from_stream(
contents: &ObjectStreamContents,
index: u32,
) -> Option<&Object>Get a specific object from a parsed object stream by its index.