pub enum SecurityError {
InvalidPassword,
UnsupportedVersion(u32, u32),
MissingKey(String),
Crypto(CryptoError),
}Expand description
Errors from the security handler.
Variants
InvalidPassword
The supplied password does not match owner or user password.
UnsupportedVersion(u32, u32)
The encryption version/revision is not supported.
MissingKey(String)
A required key is missing from the encryption dictionary.
Crypto(CryptoError)
An underlying cryptographic error.