Module xref_stream

Module xref_stream 

Cross-reference stream parsing (PDF 1.5+).

PDF 1.5+ allows cross-reference data to be stored as a stream object instead of or in addition to the traditional xref table. The stream dictionary also serves as the trailer dictionary.

Functions

parse_xref_stream
Parse a cross-reference stream at the given offset.