Linearization detection.
A linearized PDF has its first indirect object contain a /Linearized key
in its dictionary. This module detects this marker and extracts the
linearization parameters.
Structs
- Linearized
Info - Information extracted from a linearization dictionary.
Functions
- detect_
linearized - Detect whether a PDF is linearized by checking the first indirect object.