Cross-reference stream parsing (PDF 1.5+).
PDF 1.5+ allows cross-reference data to be stored as a stream object
instead of or in addition to the traditional xref table. The stream
dictionary also serves as the trailer dictionary.
Functions
- parse_
xref_ stream - Parse a cross-reference stream at the given offset.